package ru.dbotthepony.kstarbound.io

import ru.dbotthepony.kommons.io.readVarInt
import ru.dbotthepony.kommons.io.writeVarInt
import java.io.InputStream
import java.io.OutputStream

class ByteKey(private vararg val bytes: Byte) {
	override fun equals(other: Any?): Boolean {
		return this === other || other is ByteKey && other.bytes.contentEquals(bytes)
	}

	fun write(stream: OutputStream) {
		stream.writeVarInt(bytes.size)
		stream.write(bytes)
	}

	override fun hashCode(): Int {
		return bytes.contentHashCode()
	}

	override fun toString(): String {
		return "ByteKey[${bytes.joinToString(", ")}]"
	}
}

fun InputStream.readByteKey(): ByteKey {
	return ByteKey(*ByteArray(readVarInt()).also { read(it) })
}

fun OutputStream.writeByteKey(key: ByteKey) {
	key.write(this)
}
